@@ -384,5 +384,35 @@ atk_coord_type_get_type (void)
   return etype;
 }
 
+/* enumerations from "atkvalue.h" */
+GType
+atk_value_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { ATK_VALUE_VERY_WEAK, "ATK_VALUE_VERY_WEAK", "very-weak" },
+      { ATK_VALUE_WEAK, "ATK_VALUE_WEAK", "weak" },
+      { ATK_VALUE_ACCEPTABLE, "ATK_VALUE_ACCEPTABLE", "acceptable" },
+      { ATK_VALUE_STRONG, "ATK_VALUE_STRONG", "strong" },
+      { ATK_VALUE_VERY_STRONG, "ATK_VALUE_VERY_STRONG", "very-strong" },
+      { ATK_VALUE_VERY_LOW, "ATK_VALUE_VERY_LOW", "very-low" },
+      { ATK_VALUE_LOW, "ATK_VALUE_LOW", "low" },
+      { ATK_VALUE_MEDIUM, "ATK_VALUE_MEDIUM", "medium" },
+      { ATK_VALUE_HIGH, "ATK_VALUE_HIGH", "high" },
+      { ATK_VALUE_VERY_HIGH, "ATK_VALUE_VERY_HIGH", "very-high" },
+      { ATK_VALUE_VERY_BAD, "ATK_VALUE_VERY_BAD", "very-bad" },
+      { ATK_VALUE_BAD, "ATK_VALUE_BAD", "bad" },
+      { ATK_VALUE_GOOD, "ATK_VALUE_GOOD", "good" },
+      { ATK_VALUE_VERY_GOOD, "ATK_VALUE_VERY_GOOD", "very-good" },
+      { ATK_VALUE_BEST, "ATK_VALUE_BEST", "best" },
+      { ATK_VALUE_LAST_DEFINED, "ATK_VALUE_LAST_DEFINED", "last-defined" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("AtkValueType", values);
+  }
+  return etype;
+}
+
 
 
